@@ -20,11 +20,10 @@ AboutData::AboutData()
                  QStringLiteral(AKREGATOR_VERSION),
                  i18n("A KDE Feed Reader"),
                  KAboutLicense::GPL,
-                 i18n("Copyright © 2004–2021 Akregator authors"),
+                 i18n("Copyright © 2004–%1 Akregator authors", QStringLiteral("2022")),
                  QString(),
                  QStringLiteral("https://userbase.kde.org/Akregator"))
 {
-    setOrganizationDomain("kde.org"); // needed to get org.kde.akregator used for DBUS
     addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     addAuthor(i18n("Frank Osterfeld"), i18n("Former maintainer"), QStringLiteral("osterfeld@kde.org"));
     addAuthor(i18n("Teemu Rytilahti"), i18n("Developer"), QStringLiteral("tpr@d5k.net"));
@@ -44,6 +43,4 @@ AboutData::AboutData()
     addCredit(i18n("Philipp Droessler"), i18n("Gentoo Ebuild"), QStringLiteral("kingmob@albert-unser.net"));
 }
 
-AboutData::~AboutData()
-{
-}
+AboutData::~AboutData() = default;
